@@ -254,7 +254,8 @@ char *name;
 	/* find just the basename */
 	while (*name == ' ')
 	    name++;
-	for (base = name+strlen(name); base > name && base[-1] != '/'; --base)
+	for (base = name+strlen(name);
+		    base > name && base[-1] != '/' && base[-1] != '\\'; --base)
 	    continue;
 
 	for (dbcp = dbcat; dbcp < &dbcat[ndbcat]; dbcp++)
@@ -539,7 +540,8 @@ int nodups;
 
 	/* report just base of fn */
     ok:
-	for (base = fn+strlen(fn); base > fn && base[-1] != '/'; --base)
+	for (base = fn+strlen(fn);
+		    base > fn && base[-1] != '/' && base[-1] != '\\'; --base)
 	    continue;
 
 	/* set up to run the progress meter based on file position */
@@ -954,7 +956,8 @@ char *name;
 	/* eh?? */
 	printf ("Bug! catalog disappeared after sorting: %s\n", name);
 	exit(1);
+	return (0);	/* for lint */
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: db.c,v $ $Date: 2000/09/12 04:53:13 $ $Revision: 1.16 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: db.c,v $ $Date: 2001/10/10 05:43:15 $ $Revision: 1.18 $ $Name:  $"};
