@@ -121,6 +121,8 @@ static int tyc_on;		/* whether tycho is currently on */
 static char *tyc_fn;		/* tycho filename */
 static int nodup_on;		/* whether dup checking is on */
 
+static char fscategory[] = "Field stars";
+
 /* call to set up without actually bringing up the menus.
  */
 void
@@ -445,8 +447,8 @@ fs_create_fsshell()
 	fsshell_w = XtCreatePopupShell ("FieldStars", topLevelShellWidgetClass,
 							toplevel_w, args, n);
 	set_something (fsshell_w, XmNcolormap, (XtArgVal)xe_cm);
-	sr_reg (fsshell_w, "XEphem*FieldStars.x", dbcategory, 0);
-	sr_reg (fsshell_w, "XEphem*FieldStars.y", dbcategory, 0);
+	sr_reg (fsshell_w, "XEphem*FieldStars.x", fscategory, 0);
+	sr_reg (fsshell_w, "XEphem*FieldStars.y", fscategory, 0);
 
 	n = 0;
 	XtSetArg (args[n], XmNmarginHeight, 10); n++;
@@ -476,7 +478,7 @@ fs_create_fsshell()
 	    cdtf_w = XmCreateTextField (fsform_w, "GSCCDDirectory", args, n);
 	    wtip (cdtf_w, "Pathname to the root of the CDROM when mounted");
 	    XtManageChild (cdtf_w);
-	    sr_reg (cdtf_w, NULL, dbcategory, 1);
+	    sr_reg (cdtf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -493,7 +495,7 @@ fs_create_fsshell()
 	    set_xmstring (cdtb_w, XmNlabelString, "ASP CDROM Directory:");
 	    wtip (cdtb_w, "Whether to use the ASP CDROM for GSC stars");
 	    XtManageChild (cdtb_w);
-	    sr_reg (cdtb_w, NULL, dbcategory, 1);
+	    sr_reg (cdtb_w, NULL, fscategory, 1);
 
 	    /* make the GSC Cache toggle/text */
 
@@ -506,7 +508,7 @@ fs_create_fsshell()
 	    defaultTextFN (chtf_w, 0, getShareDir(), "catalogs/gsc");
 	    wtip (chtf_w, "Pathname to the GSC subdirectory");
 	    XtManageChild (chtf_w);
-	    sr_reg (chtf_w, NULL, dbcategory, 1);
+	    sr_reg (chtf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -523,7 +525,7 @@ fs_create_fsshell()
 	    set_xmstring (chtb_w, XmNlabelString,  "Local Cache Directory:");
 	    wtip (chtb_w, "Whether to use a local disk for GSC stars");
 	    XtManageChild (chtb_w);
-	    sr_reg (chtb_w, NULL, dbcategory, 1);
+	    sr_reg (chtb_w, NULL, fscategory, 1);
 
 	    /* make the GSC network toggle/text */
 
@@ -533,8 +535,8 @@ fs_create_fsshell()
 	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
 	    XtSetArg (args[n], XmNcolumns, 60); n++;
 	    nettf_w = XmCreateTextField (fsform_w, "XEphemdbdURL", args, n);
-	    wtip (nettf_w, "URL (/<host>/.../xephemdbd.pl) from which to fetch GSC stars");
-	    sr_reg (nettf_w, NULL, dbcategory, 1);
+	    wtip (nettf_w, "URL from which to fetch GSC stars");
+	    sr_reg (nettf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -550,7 +552,7 @@ fs_create_fsshell()
 							    (XtPointer)NETTB);
 	    set_xmstring (nettb_w, XmNlabelString, "Internet to xephemdbd:");
 	    wtip (nettb_w,"Whether to use an Internet XEphem server for stars");
-	    sr_reg (nettb_w, NULL, dbcategory, 1);
+	    sr_reg (nettb_w, NULL, fscategory, 1);
 	    XtManageChild (nettb_w);
 	    XtManageChild (nettf_w);
 
@@ -568,7 +570,7 @@ fs_create_fsshell()
 	    set_xmstring (etb_w, XmNlabelString, "Internet to ESO");
 	    wtip(etb_w,"Whether to use the Internet to ESO to fetch GSC stars");
 	    XtManageChild (etb_w);
-	    sr_reg (etb_w, NULL, dbcategory, 1);
+	    sr_reg (etb_w, NULL, fscategory, 1);
 
 	/* make the USNO section title */
 
@@ -593,7 +595,7 @@ fs_create_fsshell()
 		"Pathname of A1.0, SA1.0 etc catalog series root directory");
 	    defaultTextFN (notf_w, 0, getShareDir(), "catalogs/usno");
 	    XtManageChild (notf_w);
-	    sr_reg (notf_w, NULL, dbcategory, 1);
+	    sr_reg (notf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -608,7 +610,7 @@ fs_create_fsshell()
 	    set_xmstring (notb_w, XmNlabelString, "Root directory: ");
 	    wtip (notb_w, "Whether to access a USNO catalog");
 	    XtManageChild (notb_w);
-	    sr_reg (notb_w, NULL, dbcategory, 1);
+	    sr_reg (notb_w, NULL, fscategory, 1);
 
 	/* make the PM section title */
 
@@ -632,7 +634,7 @@ fs_create_fsshell()
 	    wtip (ppmtf_w, "Full pathname of ppm.xe2 file");
 	    defaultTextFN (ppmtf_w, 0, getShareDir(), "catalogs/ppm.xe2");
 	    XtManageChild (ppmtf_w);
-	    sr_reg (ppmtf_w, NULL, dbcategory, 1);
+	    sr_reg (ppmtf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -647,7 +649,7 @@ fs_create_fsshell()
 	    set_xmstring (ppmtb_w, XmNlabelString, "PPM catalog: ");
 	    wtip (ppmtb_w, "Whether to access the PPM catalog, ppm.xe2");
 	    XtManageChild (ppmtb_w);
-	    sr_reg (ppmtb_w, NULL, dbcategory, 1);
+	    sr_reg (ppmtb_w, NULL, fscategory, 1);
 
 	    /* make the Tycho toggle/text */
 
@@ -660,7 +662,7 @@ fs_create_fsshell()
 	    wtip (tyctf_w, "Full pathname of hiptyc2.xe2 file");
 	    defaultTextFN (tyctf_w, 0, getShareDir(), "catalogs/hiptyc2.xe2");
 	    XtManageChild (tyctf_w);
-	    sr_reg (tyctf_w, NULL, dbcategory, 1);
+	    sr_reg (tyctf_w, NULL, fscategory, 1);
 
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
@@ -675,7 +677,7 @@ fs_create_fsshell()
 	    set_xmstring (tyctb_w, XmNlabelString, "Hipparcos + Tycho2: ");
 	    wtip (tyctb_w, "Whether to access the combined Hipparcos and Tycho2 catalog");
 	    XtManageChild (tyctb_w);
-	    sr_reg (tyctb_w, NULL, dbcategory, 1);
+	    sr_reg (tyctb_w, NULL, fscategory, 1);
 
 	    /* enforce and tie together as 1-of-2 pair */
 	    if(XmToggleButtonGetState(ppmtb_w) &&
@@ -700,7 +702,7 @@ fs_create_fsshell()
 	    wtip (nodupt_w,
 	      "When loading, skip objects which are very similar to ones already in memory");
 	    XtManageChild (nodupt_w);
-	    sr_reg (nodupt_w, NULL, dbcategory, 1);
+	    sr_reg (nodupt_w, NULL, fscategory, 1);
 
 	/* make the controls across the bottom under a separator */
 
@@ -1029,4 +1031,4 @@ XtPointer call;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: fsmenu.c,v $ $Date: 2000/09/11 07:15:11 $ $Revision: 1.14 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: fsmenu.c,v $ $Date: 2001/10/04 20:30:32 $ $Revision: 1.16 $ $Name:  $"};
