@@ -40,7 +40,7 @@ static int moreObjF P_((ObjF **opp, int nop, int nnew));
  */
 int
 gscnetfetch (url, np, ra, dec, fov, mag, opp, nop, msg)
-char *url;	/* /<host>/xephemdbd.pl or whatever */
+char *url;	/* http://<host>/xephemdbd.pl or whatever */
 Now *np;	/* current circumstances */
 double ra, dec;	/* RA/Dec of center of view, rads, J2000 */
 double fov;	/* diamater of field of view, rads */
@@ -57,7 +57,12 @@ static char ofmt[] = "http://%s%s?VERSION=3&FMT=EDB&CENTRIC=GEO&PRECES=ASTRO&GS=
 	int n;
 
 	/* pull out the host from url */
-	h0p = url[0] == '/' ? url+1 : url;
+	if ((h0p = strstr (url, "http://")) || (h0p = strstr (url, "HTTP://")))
+	    h0p += 7;
+	else if (url[0] == '/')
+	    h0p = url+1;
+	else
+	    h0p = url;
 	h1p = strchr (h0p, '/');
 	if (!h1p) {
 	    (void) strcpy (msg, "No host in xephemdbd url");
@@ -216,4 +221,4 @@ int nnew;
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: gscnet.c,v $ $Date: 2000/10/20 19:31:54 $ $Revision: 1.5 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: gscnet.c,v $ $Date: 2001/10/04 20:30:32 $ $Revision: 1.6 $ $Name:  $"};
