@@ -5,6 +5,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
 #include <math.h>
 #include <time.h>
 
@@ -13,7 +14,6 @@
 #endif
 
 #include <X11/Xlib.h>
-#include <X11/keysym.h>
 #include <Xm/Xm.h>
 #include <Xm/Frame.h>
 #include <Xm/Label.h>
@@ -44,7 +44,6 @@ extern double atod P_((char *buf));
 extern int any_ison P_((void));
 extern int listing_ison P_((void));
 extern int plot_ison P_((void));
-extern int sf_ison P_((void));
 extern int srch_eval P_((double Mjd, double *tmincp));
 extern int tz_fromsys P_((Now *np));
 extern void all_update P_((Now *np, int how_much));
@@ -52,6 +51,7 @@ extern void buttonAsButton P_((Widget w, int whether));
 extern void calm_set P_((Now *np));
 extern void db_invalidate P_((void));
 extern void db_loadinitial P_((void));
+extern void db_update P_((Obj *op));
 extern void defaultTextFN P_((Widget w, int setcols, char *x, char *y));
 extern void dm_riset P_((Now *np, Obj *op, RiseSet *rsp));
 extern void f_date P_((Widget w, double jd));
@@ -108,37 +108,39 @@ typedef struct {
 #define	MAXSITENL	25	/* max site name after abbreviation */
 
 static void create_main_form P_((Widget mainrc));
-static void create_dstpm P_((void));
+static void create_pixmaps P_((void));
 static void make_prompts P_((Widget p_w, int pc, char *title, char *tip,
     Field *fp, int nfp));
 static Widget fw P_((int fid));
-static void mm_step_now P_((void));
+static void mm_step_now P_((int rev));
 static void mm_set_step_code P_((char *bp));
 static void mm_set_buttons P_((int whether));
 static void mm_activate_cb P_((Widget w, XtPointer client, XtPointer call));
 static void mm_initres P_((void));
+static void mm_pms P_((void));
 static void mm_set_alt_prompts P_((Field *fp));
 static void mm_timer_cb P_((XtPointer client, XtIntervalId *id));
 static void mm_stop P_((void));
 static void mm_step_cb P_((Widget w, XtPointer client, XtPointer call));
 static void mm_go_action P_((Widget w, XEvent *e, String *args,
-	Cardinal *nargs));
-static void mm_go_doit P_((void));
-static void mm_go P_((void));
-static void print_tminc P_((int force));
+    Cardinal *nargs));
+static void keepnow_cb P_((Widget w, XtPointer client, XtPointer call));
+static void mm_gostop P_((int dir));
+static void mm_go P_((int dir));
+static void print_tminc P_((void));
 static void print_updating P_((void));
 static void print_idle P_((void));
-static void print_running P_((void));
+static void print_running P_((int rev));
 static void print_extrunning P_((void));
 static void print_status P_((char *s));
-static void print_nstep P_((int force));
-static void print_mspause P_((int force));
+static void print_nstep P_((void));
+static void print_mspause P_((void));
 static int chg_fld P_((char *bp, Field *fp));
 static void prompt_ok_cb P_((Widget w, XtPointer client, XtPointer call));
 static void prompt P_((Field *fp));
 static Widget create_prompt_w P_((Widget *wp));
 static void mm_now P_((int all));
-static void mm_twilight P_((int force));
+static void mm_twilight P_((void));
 static void mm_newcir P_((int y));
 static void mm_newcir_cb P_((XtPointer client, XtIntervalId *id));
 static void ext_fileask P_((void));
@@ -191,8 +193,8 @@ static int mm_selecting;        /* set while our fields are being selected */
 
 #define	NO_PAUSE_DELAY	25	/* min ms delay to use, regardless of mspause */
 #define	NC_BLINK_DELAY	200	/* ms between NEW CIRCUMSTANCES state changes */
-
-#define	MANYSTEPS	1000000
+#define	MANYSTEPS	1000000	/* "many" steps */
+#define	NOWPAUSE	10000	/* default Pause when staying in sync, ms */
 
 /* field ids
  * N.B. must be in same order as they appear in mm_field_map[].
@@ -244,10 +246,10 @@ static Field mm_field_map[] = {
 	"Local time (h:m:s): ",				"Local Time:", "LT"},
     {"DeltaT", DT_FID, 0, "TT - UT1, seconds",
 	dummy,						"Delta T:", "DeltaT",
-	{  "Fixed value for TT - UT1, in seconds,\n\
-or type `Auto' to use model: ",
-	   "Fixed value for TT - UT1, in seconds\n\
-('Auto' will be turned off): ",
+	{  "Enter fixed value for TT - UT1, in seconds,\n\
+or press Auto to use model: ",
+	   "Enter fixed value for TT - UT1, in seconds\n\
+(Automatic model will be turned off): ",
 	   NULL
 	}
     },
@@ -297,9 +299,9 @@ or enter any time step as follows:\n\
 	    "Atmospheric pressure (mBar):"
 	}
     },
-    {"Epoch", EPOCH_FID, 1,
+    {"Equinox", EPOCH_FID, 1,
 	"Precession epoch: EOD for full apparent, fixed year for astrometric",
-	"Epoch (decimal year): ",			"Epoch:", NULL},
+	"Precession Epoch (decimal year): ",		"Equinox:", NULL},
 };
 
 #define	NFM	XtNumber(mm_field_map)
@@ -309,6 +311,8 @@ static Widget newcir_w;
 static Widget status_w;
 static Widget go_w;
 static Widget ext_w;
+static Widget keepnow_w;
+static Widget stepF_w, stepB_w;
 
 /* stuff to manage the step control facility.
  * we support a variety of ways time can be incremented.
@@ -329,10 +333,10 @@ typedef struct {
 } StepOption;
 /* N.B. leave RT Clock first!! see the RTC_SS_OPTION macro */
 static StepOption step_options[] = {
-    {"RT Clock",	RTC_SS,		 0.0,	"Track computer clock"},
+    {"RT Clock",	RTC_SS,		 0.0,	"Advance by elapsed time"},
     {"24:00:00",	FIXED_SS,	24.0,	"Step by 1 day"},
-    {"1:00:00",		FIXED_SS,	1.0,	"Step by 1 hour"},
-    {"0:01:00",		FIXED_SS,	1./60.,	"Step by 1 minute"},
+    {" 1:00:00",	FIXED_SS,	1.0,	"Step by 1 hour"},
+    {" 0:01:00",	FIXED_SS,	1./60.,	"Step by 1 minute"},
     {"Dawn",		STEPDAWN_SS,	 0.0,	"Step to next dawn"},
     {"Dusk",		STEPDUSK_SS,	 0.0,	"Step to next dusk"},
     {"Sun rise",	STEPSUNRISE_SS,	 0.0,	"Step to next sun rise"},
@@ -349,11 +353,10 @@ static StepOption step_options[] = {
 #define	RTC_SS_OPTION	(&step_options[0])
 
 /* current step_option.
- * how we init it here determines is the default value.
+ * how we init it here determines its default value.
  * if this is 0 it means just use tminc, period.
  */
 static StepOption *mm_step_option = RTC_SS_OPTION;
-static int mm_reverse;		/* set to go backwards in time */
 
 /* site name, or NULL if none.
  * absitename[] is an abbreviated version for display purposes. it is only
@@ -363,9 +366,9 @@ static int mm_reverse;		/* set to go backwards in time */
 static char *msitename;
 static char absitename[MAXSITENL];
 
-/* map the Update action to the mm_go_action() handler function */
+/* map the XeGo action to the mm_go_action() handler function */
 static XtActionsRec mm_actions[] = {
-	{"XeUpdate", mm_go_action}
+	{"XeGo", mm_go_action}
 };
 
 
@@ -379,6 +382,55 @@ static unsigned char dst_bits[] = {
 static Pixmap dst_pm;		/* pixmap when autotz is on */
 static Widget dst_w;		/* label for dst_pm */
 
+/* 8 moon bitmaps */
+#define	moon_width	13
+#define	moon_height	13
+static unsigned char moonwaxc_bits[] = {
+   0xf8, 0x03, 0x7e, 0x0c, 0xfe, 0x08, 0xff, 0x10, 0xff, 0x11, 0xff, 0x11,
+   0xff, 0x11, 0xff, 0x11, 0xff, 0x11, 0xff, 0x10, 0xfe, 0x08, 0x7e, 0x0c,
+   0xf8, 0x03};
+static unsigned char moon1q_bits[] = {
+   0xf8, 0x03, 0x7e, 0x0c, 0x7e, 0x08, 0x7f, 0x10, 0x7f, 0x10, 0x7f, 0x10,
+   0x7f, 0x10, 0x7f, 0x10, 0x7f, 0x10, 0x7f, 0x10, 0x7e, 0x08, 0x7e, 0x0c,
+   0xf8, 0x03};
+static unsigned char moonwaxg_bits[] = {
+   0xf8, 0x03, 0x3e, 0x0c, 0x1e, 0x08, 0x0f, 0x10, 0x0f, 0x10, 0x0f, 0x10,
+   0x0f, 0x10, 0x0f, 0x10, 0x0f, 0x10, 0x0f, 0x10, 0x1e, 0x08, 0x3e, 0x0c,
+   0xf8, 0x03};
+static unsigned char moonfull_bits[] = {
+   0xf8, 0x03, 0x06, 0x0c, 0x02, 0x08, 0x01, 0x10, 0x01, 0x10, 0x01, 0x10,
+   0x01, 0x10, 0x01, 0x10, 0x01, 0x10, 0x01, 0x10, 0x02, 0x08, 0x06, 0x0c,
+   0xf8, 0x03};
+static unsigned char moonwang_bits[] = {
+   0xf8, 0x03, 0x86, 0x0f, 0x02, 0x0f, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e,
+   0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x01, 0x1e, 0x02, 0x0f, 0x86, 0x0f,
+   0xf8, 0x03};
+static unsigned char moon3q_bits[] = {
+   0xf8, 0x03, 0xc6, 0x0f, 0xc2, 0x0f, 0xc1, 0x1f, 0xc1, 0x1f, 0xc1, 0x1f,
+   0xc1, 0x1f, 0xc1, 0x1f, 0xc1, 0x1f, 0xc1, 0x1f, 0xc2, 0x0f, 0xc6, 0x0f,
+   0xf8, 0x03};
+static unsigned char moonwanc_bits[] = {
+   0xf8, 0x03, 0xc6, 0x0f, 0xe2, 0x0f, 0xe1, 0x1f, 0xf1, 0x1f, 0xf1, 0x1f,
+   0xf1, 0x1f, 0xf1, 0x1f, 0xf1, 0x1f, 0xe1, 0x1f, 0xe2, 0x0f, 0xc6, 0x0f,
+   0xf8, 0x03};
+static unsigned char moonnew_bits[] = {
+   0xf8, 0x03, 0xfe, 0x0f, 0xfe, 0x0f, 0xff, 0x1f, 0xff, 0x1f, 0xff, 0x1f,
+   0xff, 0x1f, 0xff, 0x1f, 0xff, 0x1f, 0xff, 0x1f, 0xfe, 0x0f, 0xfe, 0x0f,
+   0xf8, 0x03};
+#define	NMOONBM		8
+static Pixmap moon_pm[NMOONBM];	/* bitmaps of basic moon phases, full -> full */
+static Widget moon_w;		/* label for a moon_pm */
+
+/* sun bitmap */
+#define sun_width 13
+#define sun_height 13
+static unsigned char sun_bits[] = {
+   0x48, 0x02, 0xf2, 0x09, 0x0c, 0x06, 0x05, 0x14, 0x02, 0x08, 0x02, 0x08,
+   0x03, 0x18, 0x02, 0x08, 0x02, 0x08, 0x05, 0x14, 0x0c, 0x06, 0xf2, 0x09,
+   0x48, 0x02};
+static Pixmap sun_pm;		/* pixmap when sun is up */
+static Widget sun_w;		/* label for sun_pm */
+
 
 /* called exactly once when the main form is made.
  * create and manage all the widgets as children of the mainrc.
@@ -389,10 +441,7 @@ Widget mainrc;
 {
 	/* create the main form */
 	create_main_form(mainrc);
-	create_dstpm();
-
-	/* connect up an action routine to handle XeUpdate */
-	XtAppAddActions (xe_app, mm_actions, XtNumber(mm_actions));
+	create_pixmaps();
 
 	/* init resources and Now */
 	mm_initres();
@@ -404,22 +453,29 @@ Widget mainrc;
 	fs_create();
 }
 
+/* connect up an action routine to handle XeUpdate */
+void
+mm_connActions()
+{
+	XtAppAddActions (xe_app, mm_actions, XtNumber(mm_actions));
+}
+
 /* called to update after new resources are installed */
 void
 mm_newres()
 {
 	Pixel p;
 
-	/* new DST pixmap */
-	create_dstpm();
+	/* new pixmaps */
+	create_pixmaps();
 
 	/* keep newcir invisible */
 	get_something (newcir_w, XmNbackground, (XtArgVal)&p);
 	set_something (newcir_w, XmNforeground, (XtArgVal)p);
 
-	/* pulled these from mm_now() */
-	set_something (dst_w, XmNlabelPixmap,
-				    autotz ? dst_pm : XmUNSPECIFIED_PIXMAP);
+	/* redraw the pixmaps */
+	mm_pms();
+
 	calm_set (&now);
 }
 
@@ -435,10 +491,8 @@ mm_external ()
 	    ext_fileask();
 }
 
-/* callback from the main "go" button being armed or the Update button or its
- *   accelerator: if we are looping (as evidenced by an active timer) then stop,
- *   else go.
- * client is 0 for forward, 1 for reverse.
+/* callback to update forward or reverse 1 step or just go.
+ * see mm_gostop for meaning of client.
  */
 /* ARGSUSED */
 void
@@ -447,8 +501,7 @@ Widget w;
 XtPointer client;
 XtPointer call;
 {
-	mm_reverse = (int)client;
-	mm_go_doit();
+	mm_gostop ((int)client);
 }
 
 /* called by the calendar subsystem to set a new UT date.
@@ -643,18 +696,18 @@ double stepsz;	/* step size, hours */
 
 	/* init nstep and mspause to reasonable for long fast looping */
 	nstep = MANYSTEPS;
-	print_nstep(1);
+	print_nstep();
 	mspause = 0;
-	print_mspause(1);
+	print_mspause();
 
 	/* set the time increment to stepsz */
 	mm_step_option = NULL;	/* no special increment */
 	tminc = stepsz;
-	print_tminc(1);
-	print_running();
+	print_tminc();
+	print_running(0);
 
 	/* start fresh looping */
-	mm_go();
+	mm_go(0);
 }
 
 /* draw all the stuff on the managed menus.
@@ -673,21 +726,23 @@ int how_much;
 	if (nstep < 1)
 	    print_updating();
 
+	/* show nstep to show plot loops to go and
+	 * show tminc to show search convergence progress.
+	 */
+	print_nstep();
+	print_tminc();
+	print_mspause();
+
 	/* if just updating changed fields while plotting or listing
-	 * unattended then suppress most screen updates except
-	 * always show nstep to show plot loops to go and
-	 * always show tminc to show search convergence progress.
+	 * unattended then suppress most screen updates.
 	 */
-	print_nstep(how_much);
-	print_tminc(how_much);
-	print_mspause(how_much);
 	if (!how_much)
 	    f_off();
 
 	/* print all the time-related fields */
 	mm_now (how_much);
 
-	mm_twilight (how_much);
+	mm_twilight ();
 
 	/* print stuff on other menus */
 	all_update(&now, how_much);
@@ -701,18 +756,19 @@ int how_much;
 	watch_cursor(0);
 }
 
-/* (re)create the DST pixmap.
+/* (re)create the pixmaps.
  * N.B. we use the colors from status_w.
  */
 static void
-create_dstpm()
+create_pixmaps()
 {
 	Display *dsp = XtDisplay (toplevel_w);
 	Window win = RootWindow (dsp, DefaultScreen(dsp));
 	Arg args[20];
+	XColor colors[2];
 	Pixel fg, bg;
 	int d;
-	int n;
+	int i, n;
 
 	n = 0;
 	XtSetArg (args[n], XmNforeground, &fg); n++;
@@ -720,10 +776,55 @@ create_dstpm()
 	XtSetArg (args[n], XmNdepth, &d); n++;
 	XtGetValues (status_w, args, n);
 
+	/* DST indicator */
 	if (dst_pm)
 	    XFreePixmap (dsp, dst_pm);
 	dst_pm = XCreatePixmapFromBitmapData (dsp, win, (char *)dst_bits,
 					dst_width, dst_height, fg, bg, d); 
+
+	/* moons; create in full -> full */
+	for (n = 0; n < NMOONBM; n++)
+	    if (moon_pm[n])
+		XFreePixmap (dsp, moon_pm[n]);
+	moon_pm[0] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonfull_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[1] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonwang_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[2] = XCreatePixmapFromBitmapData(dsp, win, (char*)moon3q_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[3] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonwanc_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[4] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonnew_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[5] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonwaxc_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[6] = XCreatePixmapFromBitmapData(dsp, win, (char*)moon1q_bits,
+					moon_width, moon_height, fg, bg, d); 
+	moon_pm[7] = XCreatePixmapFromBitmapData(dsp, win, (char*)moonwaxg_bits,
+					moon_width, moon_height, fg, bg, d); 
+
+	/* bitmaps are drawn assuming fg is darker than bg. if not, rotate by
+	 * 1/2 phase
+	 */
+	colors[0].pixel = fg;
+	colors[1].pixel = bg;
+	XQueryColors (dsp, xe_cm, colors, XtNumber(colors));
+	if (colors[0].red + colors[0].green + colors[0].blue >
+		colors[1].red + colors[1].green + colors[1].blue) {
+
+	    for (i = 0; i < NMOONBM/2; i++) {
+		Pixmap tmp = moon_pm[i];
+		Pixmap *nxt = &moon_pm[(i+NMOONBM/2)%NMOONBM];
+		moon_pm[i] = *nxt;
+		*nxt = tmp;
+	    }
+	}
+
+	/* Sun */
+	if (sun_pm)
+	    XFreePixmap (dsp, sun_pm);
+	sun_pm = XCreatePixmapFromBitmapData (dsp, win, (char *)sun_bits,
+					sun_width, sun_height, fg, bg, d); 
 }
 
 static void
@@ -829,7 +930,7 @@ Widget mainrc;
 	XtSetArg (args[n], XmNmarginBottom, 5); n++;
 	go_w = XmCreatePushButton (mrc_w, "MainUpdate", args, n);
 	XtAddCallback (go_w, XmNactivateCallback, mm_go_cb, 0);
-	wtip (go_w, "Start and stop the main execution loop");
+	wtip (go_w, "Run or stop the main execution loop");
 	set_xmstring (go_w, XmNlabelString, "Update");
 	XtManageChild (go_w);
 }
@@ -877,6 +978,37 @@ int nfp;
 	    wtip (b_w, tip);
 	    XtManageChild (b_w);
 
+	} else if (!strcmp (title, "Night")) {
+	    /* N.B. hack in sun and moon PMs */
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNlabelType, XmPIXMAP); n++;
+	    sun_w = XmCreateLabel (f_w, "SunUp", args, n);
+	    wtip (sun_w, "Shows a Sun when it is above local horizontal");
+	    XtManageChild (sun_w);
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNlabelType, XmPIXMAP); n++;
+	    moon_w = XmCreateLabel (f_w, "MoonUp", args, n);
+	    wtip (moon_w, "Shows a Moon when it is above local horizontal");
+	    XtManageChild (moon_w);
+
+	    n = 0;
+	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
+	    XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNleftWidget, sun_w); n++;
+	    XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
+	    XtSetArg (args[n], XmNrightWidget, moon_w); n++;
+	    XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
+	    b_w = XmCreateLabel (f_w, "MTL", args, n);
+	    set_xmstring (b_w, XmNlabelString, title);
+	    wtip (b_w, tip);
+	    XtManageChild (b_w);
+
 	} else {
 	    n = 0;
 	    XtSetArg (args[n], XmNtopAttachment, XmATTACH_FORM); n++;
@@ -890,7 +1022,6 @@ int nfp;
 	}
 
 	for (lfp = fp + nfp; fp < lfp; fp++) {
-	    Widget w;
 
 	    /* if GAP just mark a separator */
 	    if (fp->id == GAP) {
@@ -899,20 +1030,81 @@ int nfp;
 		XtSetArg (args[n], XmNtopWidget, b_w); n++;
 		XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
 		XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
-		w = XmCreateSeparator (f_w, "GapSep", args, n);
-		XtManageChild (w);
+		b_w = XmCreateSeparator (f_w, "GapSep", args, n);
+		XtManageChild (b_w);
+
+		if (strcmp (title, "Night"))
+		    continue;
+
+		/* N.B. hacks in Looping title for + - and Now PBs. */
 
 		n = 0;
 		XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
-		XtSetArg (args[n], XmNtopWidget, w); n++;
-		XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+		XtSetArg (args[n], XmNtopWidget, b_w); n++;
 		XtSetArg (args[n], XmNrightAttachment, XmATTACH_FORM); n++;
+		XtSetArg (args[n], XmNmarginWidth, 0); n++;
+		XtSetArg (args[n], XmNmarginHeight, 0); n++;
+		XtSetArg (args[n], XmNmarginTop, 0); n++;
+		XtSetArg (args[n], XmNmarginBottom, 0); n++;
+		XtSetArg (args[n], XmNmarginLeft, 0); n++;
+		XtSetArg (args[n], XmNmarginRight, 0); n++;
+		keepnow_w = XmCreatePushButton (f_w, "Now", args, n);
+		XtAddCallback (keepnow_w, XmNactivateCallback, keepnow_cb, 0);
+		wtip (keepnow_w,
+		    "Set looping to stay in sync with computer clock @ Pause intervals");
+		XtManageChild (keepnow_w);
+
+		n = 0;
+		XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNtopWidget, b_w); n++;
+		XtSetArg (args[n], XmNleftAttachment, XmATTACH_FORM); n++;
+		XtSetArg (args[n], XmNmarginWidth, 0); n++;
+		XtSetArg (args[n], XmNmarginHeight, 0); n++;
+		XtSetArg (args[n], XmNmarginTop, 0); n++;
+		XtSetArg (args[n], XmNmarginBottom, 0); n++;
+		XtSetArg (args[n], XmNmarginLeft, 0); n++;
+		XtSetArg (args[n], XmNmarginRight, 0); n++;
+		stepB_w = XmCreatePushButton (f_w, "SB", args, n);
+		XtAddCallback (stepB_w, XmNactivateCallback, mm_go_cb,
+								(XtPointer)-1);
+		set_xmstring (stepB_w, XmNlabelString, "-1");
+		wtip (stepB_w, "Back one Step");
+		XtManageChild (stepB_w);
+
+		n = 0;
+		XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNtopWidget, b_w); n++;
+		XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNleftWidget, stepB_w); n++;
+		XtSetArg (args[n], XmNmarginWidth, 0); n++;
+		XtSetArg (args[n], XmNmarginHeight, 0); n++;
+		XtSetArg (args[n], XmNmarginTop, 0); n++;
+		XtSetArg (args[n], XmNmarginBottom, 0); n++;
+		XtSetArg (args[n], XmNmarginLeft, 0); n++;
+		XtSetArg (args[n], XmNmarginRight, 0); n++;
+		stepF_w = XmCreatePushButton (f_w, "SF", args, n);
+		XtAddCallback (stepF_w, XmNactivateCallback, mm_go_cb,
+								(XtPointer)1);
+		set_xmstring (stepF_w, XmNlabelString, "+1");
+		wtip (stepF_w, "Forward one Step");
+		XtManageChild (stepF_w);
+
+		n = 0;
+		XtSetArg (args[n], XmNtopAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNtopWidget, b_w); n++;
+		XtSetArg (args[n], XmNleftAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNleftWidget, stepF_w); n++;
+		XtSetArg (args[n], XmNrightAttachment, XmATTACH_WIDGET); n++;
+		XtSetArg (args[n], XmNrightWidget, keepnow_w); n++;
 		XtSetArg (args[n], XmNalignment, XmALIGNMENT_CENTER); n++;
 		b_w = XmCreateLabel (f_w, "GL", args, n);
-		set_xmstring (b_w, XmNlabelString, "Looping");	/* hack! */
+		set_xmstring (b_w, XmNlabelString, "Looping");
 		wtip (b_w,
 			"Controls to set up automatic time stepping behavior");
 		XtManageChild (b_w);
+
+		b_w = keepnow_w;	/* PB is taller than label */
+
 		continue;
 	    }
 
@@ -1003,6 +1195,11 @@ int whether;
 	    else
 		buttonAsButton (fp->pb_w, fp->prompt != NULL);
 	}
+
+	/* also the special Looping PBs */
+	buttonAsButton (keepnow_w, !whether);
+	buttonAsButton (stepF_w, !whether);
+	buttonAsButton (stepB_w, !whether);
 }
 
 /* callback from any of the main menu buttons being activated.
@@ -1030,6 +1227,33 @@ XtPointer call;
 	}
 }
 
+/* called when user wants XEphem time to stay in sync with computer */
+/* ARGSUSED */
+static void
+keepnow_cb (w, client, call)
+Widget w;
+XtPointer client;
+XtPointer call;
+{
+	/* RT Clock stepping */
+	set_t0 (&now);
+	mm_step_option = RTC_SS_OPTION;
+
+	/* many steps */
+	nstep = MANYSTEPS;
+
+	/* use same pause unless 0 */
+	if (mspause == 0)
+	    mspause = NOWPAUSE;
+
+	/* set to computer time */
+	time_fromsys (&now);
+	mm_newcaldate (mjd);
+
+	print_running(0);
+	mm_go(0);
+}
+
 /* set things to their initial resource settings */
 static void
 mm_initres()
@@ -1040,10 +1264,10 @@ mm_initres()
 	    char *res;
 	} InitMap;
 	static InitMap imap[] = {
-	    {EPOCH_FID,	"Epoch"},
-	    {ELEV_FID,	"Elevation"},
+	    {EPOCH_FID,	"Equinox"},
 	    {LAT_FID,	"Lat"},
 	    {LONG_FID,	"Long"},
+	    {ELEV_FID,	"Elevation"},
 	    {NSTEP_FID,	"NSteps"},
 	    {PAUSE_FID,	"Pause"},
 	    {PRES_FID,	"Pressure"},
@@ -1054,13 +1278,22 @@ mm_initres()
 	    {TZONE_FID,	"TZone"},
 	    {TZN_FID,	"TZName"},
 	    {SITE_FID,	"Sitename"},	/* overrides others if valid */
+
+#if 0	    /* doing this works but how to /remove/ from res file once saved? */
+	    {JD_FID,	"JD"},		/* overrides Now if valid */
+	    {UT_FID,	"UTCTime"},	/* overrides Now if valid */
+	    {UD_FID,	"UTCDate"},	/* overrides Now if valid */
+	    {LT_FID,	"LTime"},	/* overrides Now if valid */
+	    {LD_FID,	"LDate"},	/* overrides Now if valid */
+	    {LST_FID,	"LST"},		/* overrides Now if valid */
+#endif
 	};
 	int i;
 
 	/* init to now first */
 	time_fromsys (&now);
 
-	/* then scan other fields (may change timezone) */
+	/* then scan other fields so they can override */
 	for (i = 0; i < XtNumber(imap); i++) {
 	    char *cp = getXRes (imap[i].res, NULL);
 	    if (cp)
@@ -1110,7 +1343,7 @@ XtPointer client;
 XtIntervalId *id;
 {
 	mm_interval_id = 0; 
-	mm_go();
+	mm_go(0);
 }
 
 /* stop running */
@@ -1120,13 +1353,19 @@ mm_stop()
 	/* close external file if in use */
 	ext_stop();
 
-	/* turn off timer, do final screen update if last was partial */
+	/* turn off timer */
 	if (mm_interval_id) {
 	    XtRemoveTimeOut (mm_interval_id);
 	    mm_interval_id = 0;
 	}
-	if (!(nstep <= 1 || mspause > 0))
+
+	/* do final screen update if last was partial */
+	if (nstep > 1 && mspause == 0)
 	    redraw_screen (1);
+
+	/* figure stopping probably means abandon the loop */
+	nstep = 1;
+	print_nstep ();
 	print_idle();
 
 	/* can't be a movie running now either */
@@ -1153,13 +1392,13 @@ XtPointer call;
 	else
 	    tminc = 0.0;	/* just to reset things for the next time */
 	set_t0 (&now);
-	print_tminc (1);
+	print_tminc ();
 
 	XtUnmanageChild (XtParent(XtParent(w)));
 }
 
-/* action routine associated with the Update translation.
- * arg is 0 for normal direction, 1 for reverse.
+/* action routine associated with the step control accelerators.
+ * see mm_gostop() for meaning of arg.
  */
 static void
 mm_go_action (w, e, p, n)
@@ -1168,49 +1407,66 @@ XEvent *e;
 String *p;
 Cardinal *n;
 {
-	mm_reverse = (n && *n && p) ? atoi(*p) : 0;
-	mm_go_doit();
+	/* assert */
+	if (!(n && *n && p)) {
+	    printf ("Bad go_action: %p %d %p\n", n, n?*n:0, p);
+	    exit(1);
+	}
+
+	/* ok */
+	mm_gostop (atoi(*p));
 }
 
-/* just a common routine for use both by mm_go_cb() and mm_go_action(). */
+/* common routine to go or stop time.
+ * dir is number of steps to go +step (+) or -step (-), or 0 to just GO.
+ */
 static void
-mm_go_doit()
+mm_gostop(dir)
+int dir;
 {
-	if (mm_interval_id != 0) {
+	if (mm_interval_id) {
 	    mm_stop();
 	} else {
-	    if (nstep > 1)
-		print_running();
+	    if (!dir && nstep > 1)
+		print_running(0);
 	    if (!newcir && any_ison())
-		mm_now (1);	/* pick up the mm_now(1) in case of listing */
-	    mm_go();
+		mm_now (1);	/* update time fields in case of listing/etc */
+	    mm_go(dir);
 	}
 }
 
 /* increment, update all fields, and go again if more steps.
+ * dir is number of steps to go +step (+) or -step (-), or 0 to just GO.
  */
 static void
-mm_go()
+mm_go(dir)
+int dir;
 {
 	int srchdone;
 	int drawall;
 
+	/* next Now unless user just made some relevant changes */
 	if (ext_fp) {
 	    if (ext_readnext() < 0)
 		nstep = 0;
 	} else if (!newcir)
-	    mm_step_now();
+	    mm_step_now(dir < 0);
 
-	/* one more step complete */
-	nstep -= 1;
+	/* update nsteps remaining.
+	 * N.B. don't want "back" to increment when at 1
+	 */
+	if (nstep == 1)
+	    nstep = 0;
+	else
+	    nstep -= dir ? dir : 1;
 
-	/* recalculate everything and update all the fields */
-	drawall = newcir || nstep <= 1 || mspause > 0;
+	/* recalculate everything and update some fields */
+	drawall = newcir || nstep <= 1 || mspause > 0 || dir;
 	redraw_screen(drawall);
 
 	/* let searching functions change tminc and check for done */
 	srchdone = srch_eval (mjd, &tminc) < 0;
-	print_tminc(0); /* to show possibly new search increment */
+	print_tminc(); /* to show possibly new search increment */
 
 	/* update plot and listing files, now that all fields are up
 	 * to date and search function has been evaluated.
@@ -1218,15 +1474,14 @@ mm_go()
 	plot();
 	listing();
 
-	/* stop loop if a search is done or steps are done */
-	newcir = 0;
-	if (srchdone || nstep<=0) {
-	    /* return nstep to default of 1
-	     * and one final update if last didn't get everything.
-	     */
-	    nstep = 1;
-	    print_nstep (0);
+	/* stop loop if a search is done, steps are done or single-stepping */
+	if (srchdone || nstep < 1 || dir) {
+	    if (!dir || nstep < 1)
+		nstep = 1;
+	    print_nstep ();
 	    print_idle();
+
+	    /* update all fields if last didn't already */
 	    if (!drawall)
 		redraw_screen (1);
 	} else {
@@ -1235,7 +1490,7 @@ mm_go()
 	    if (mspause < NO_PAUSE_DELAY) {
 		/* 0 hogs too much */
 		ms = NO_PAUSE_DELAY;
-	    } else if (!ext_fp && mm_step_option
+	    } else if (mspause >= 1000 && !ext_fp && mm_step_option
 			       && mm_step_option->stepcode == RTC_SS) {
 		/* advance to next multiple of mspause if internal & realtime */
 		long spause = mspause/1000;
@@ -1245,6 +1500,8 @@ mm_go()
 		ms = mspause;
 	    }
 
+	    if (mm_interval_id != 0)
+		XtRemoveTimeOut (mm_interval_id);
 	    mm_interval_id = XtAppAddTimeOut (xe_app, ms, mm_timer_cb, 0);
 	}
 
@@ -1256,7 +1513,8 @@ mm_go()
  * as coded in mm_step_option and possibly tminc.
  */
 static void
-mm_step_now()
+mm_step_now(reverse)
+int reverse;
 {
 #define	RSACC	(30./3600./24.)	/* nominal rise/set accuracy, days */
 #define	BADRS (RS_NORISE|RS_NOSET|RS_ERROR|RS_CIRCUMPOLAR|RS_NEVERUP)
@@ -1274,11 +1532,11 @@ mm_step_now()
 	    if (status & BADRS) {
 		xe_msg ("No dawn.", 1);
 		nstep = 0;
-	    } else if ((mm_reverse && mjd < dawn + RSACC) ||
-					(!mm_reverse && mjd > dawn - RSACC)) {
+	    } else if ((reverse && mjd < dawn + RSACC) ||
+					(!reverse && mjd > dawn - RSACC)) {
 		Now n;
 		(void) memcpy ((void *)&n, (void *)&now, sizeof(Now));
-		n.n_mjd += mm_reverse ? -1 : 1;
+		n.n_mjd += reverse ? -1 : 1;
 		twilight_cir (&n, dip, &dawn, &dusk, &status);
 		if (status & BADRS) {
 		    xe_msg ("No dawn.", 1);
@@ -1294,11 +1552,11 @@ mm_step_now()
 	    if (status & BADRS) {
 		xe_msg ("No dusk.", 1);
 		nstep = 0;
-	    } else if ((mm_reverse && mjd < dusk + RSACC) ||
-					(!mm_reverse && mjd > dusk - RSACC)) {
+	    } else if ((reverse && mjd < dusk + RSACC) ||
+					(!reverse && mjd > dusk - RSACC)) {
 		Now n;
 		(void) memcpy ((void *)&n, (void *)&now, sizeof(Now));
-		n.n_mjd += mm_reverse ? -1 : 1;
+		n.n_mjd += reverse ? -1 : 1;
 		twilight_cir (&n, dip, &dawn, &dusk, &status);
 		if (status & BADRS) {
 		    xe_msg ("No dusk.", 1);
@@ -1315,11 +1573,11 @@ mm_step_now()
 	    if (rs.rs_flags & BADRS) {
 		xe_msg ("No sunrise.", 1);
 		nstep = 0;
-	    } else if ((mm_reverse && mjd < rs.rs_risetm + RSACC) ||
-				(!mm_reverse && mjd > rs.rs_risetm - RSACC)) {
+	    } else if ((reverse && mjd < rs.rs_risetm + RSACC) ||
+				(!reverse && mjd > rs.rs_risetm - RSACC)) {
 		Now n;
 		(void) memcpy ((void *)&n, (void *)&now, sizeof(Now));
-		n.n_mjd += mm_reverse ? -1 : 1;
+		n.n_mjd += reverse ? -1 : 1;
 		dm_riset (&n, op, &rs);
 		if (rs.rs_flags & BADRS) {
 		    xe_msg ("No sunrise.", 1);
@@ -1336,11 +1594,11 @@ mm_step_now()
 	    if (rs.rs_flags & BADRS) {
 		xe_msg ("No sunset.", 1);
 		nstep = 0;
-	    } else if ((mm_reverse && mjd < rs.rs_settm + RSACC) ||
-				(!mm_reverse && mjd > rs.rs_settm - RSACC)) {
+	    } else if ((reverse && mjd < rs.rs_settm + RSACC) ||
+				(!reverse && mjd > rs.rs_settm - RSACC)) {
 		Now n;
 		(void) memcpy ((void *)&n, (void *)&now, sizeof(Now));
-		n.n_mjd += mm_reverse ? -1 : 1;
+		n.n_mjd += reverse ? -1 : 1;
 		dm_riset (&n, op, &rs);
 		if (rs.rs_flags & BADRS) {
 		    xe_msg ("No sunset.", 1);
@@ -1352,7 +1610,7 @@ mm_step_now()
 	    break;
 
 	case STEPFULLMOON_SS:
-	    if (mm_reverse) {
+	    if (reverse) {
 		/* start over a month ahead and search for prior full moon */
 		double M, mjdn, mjdf;
 		M = mjd + 32.0;
@@ -1374,7 +1632,7 @@ mm_step_now()
 	    break;
 
 	case STEPNEWMOON_SS:
-	    if (mm_reverse) {
+	    if (reverse) {
 		/* start over a month ahead and search for prior new moon */
 		double M, mjdn, mjdf;
 		M = mjd + 32.0;
@@ -1397,12 +1655,12 @@ mm_step_now()
 
 	/* FIXED_SS step options just use tminc */
 	case FIXED_SS:
-	    inc_mjd (&now, tminc, mm_reverse, 0);
+	    inc_mjd (&now, tminc, reverse, 0);
 	    break;
 
 	/* increment in real time (wrt last set_t0()) */
 	case RTC_SS:
-	    inc_mjd (&now, tminc, mm_reverse, 1);
+	    inc_mjd (&now, tminc, reverse, 1);
 	    break;
 
 	default:
@@ -1423,11 +1681,11 @@ mm_step_now()
 
 /* ARGSUSED */
 static void
-print_tminc(force)
-int force;
+print_tminc()
 {
 	Widget stpsz_w = fw(STPSZ_FID);
 	StepCode stepcode= mm_step_option ? mm_step_option->stepcode : FIXED_SS;
+	char buf[32];
 
 	switch (stepcode) {
 
@@ -1439,13 +1697,14 @@ int force;
 	case STEPFULLMOON_SS:	/* same as .. */
 	case STEPNEWMOON_SS:	/* same as .. */
 	case RTC_SS:
-	    f_string (stpsz_w, mm_step_option->title);
+	    sprintf (buf, "%9s", mm_step_option->title);
+	    f_string (stpsz_w, buf);
 	    break;
 
 	/* FIXED_SS step options just use tminc */
 	case FIXED_SS:
-	    if (fabs(tminc) >= 24.0)
-		f_double (stpsz_w, "%6.4g dy", tminc/24.0);
+	    if (fabs(tminc) >= 48.0)
+		f_double (stpsz_w, "%8.7gd", tminc/24.0);
 	    else
 		f_sexa (stpsz_w, tminc, 3, 3600);
 	    break;
@@ -1470,9 +1729,10 @@ print_idle()
 }
 
 static void
-print_running()
+print_running(reverse)
+int reverse;
 {
-	if (mm_reverse)
+	if (reverse)
 	    print_status ("Running in reverse... press Stop to stop.");
 	else
 	    print_status ("Running... press Stop to stop.");
@@ -1500,12 +1760,11 @@ char *s;
 }
 
 static void
-print_nstep(force)
-int force;
+print_nstep()
 {
-	static int last;
+	static int last = 876476;
 
-	if (force || nstep != last) {
+	if (nstep != last) {
 	    char buf[16];
 	    (void) sprintf (buf, "%7d", nstep);
 	    f_string (fw(NSTEP_FID), buf);
@@ -1514,12 +1773,11 @@ int force;
 }
 
 static void
-print_mspause(force)
-int force;
+print_mspause()
 {
-	static int last;
+	static int last = 98764;
 
-	if (force || mspause != last) {
+	if (mspause != last) {
 	    char buf[16];
 	    (void) sprintf (buf, "%7g", mspause/1000.0);
 	    f_string (fw(PAUSE_FID), buf);
@@ -1578,7 +1836,6 @@ Field *fp;
 	case UT_FID:
 	    {
 		double newutc = (mjd-mjd_day(mjd)) * 24.0;
-		rnd_second (&newutc);	/* match display precision */
 		f_scansex (newutc, bp, &newutc);
 		mjd = mjd_day(mjd) + newutc/24.0;
 	    }
@@ -1613,7 +1870,6 @@ Field *fp;
 	    {
 		double newlt = (mjd-mjd_day(mjd)) * 24.0 - tz;
 		range (&newlt, 24.0);
-		rnd_second (&newlt);	/* match display precision */
 		f_scansex (newlt, bp, &newlt);
 		mjd = mjd_day(mjd-tz/24.0) + (newlt + tz)/24.0;
 	    }
@@ -1665,7 +1921,6 @@ Field *fp;
 
 	case TZONE_FID:
 	    /* TZONE_FID */
-	    rnd_second (&tz);	/* match display precision */
 	    f_scansex (tz, bp, &tz);
 	    autotz = 0;
 	    new = 1;
@@ -1687,7 +1942,6 @@ Field *fp;
 
 	case LONG_FID:
 	    tmp = -raddeg(lng);
-	    rnd_second (&tmp);		/* match display precision */
 	    f_scansex (tmp, bp, &tmp);
 	    lng = degrad (-tmp); 	/* want <0 radians west */
 	    mm_setll (lat, lng, 0);
@@ -1696,7 +1950,6 @@ Field *fp;
 
 	case LAT_FID:
 	    tmp = raddeg(lat);
-	    rnd_second (&tmp);		/* match display precision */
 	    f_scansex (tmp, bp, &tmp);
 	    lat = degrad (tmp);
 	    mm_setll (lat, lng, 0);
@@ -1719,20 +1972,20 @@ Field *fp;
 		    xe_msg ("Twilight dip must be at least 0", 1);
 		else {
 		    dip = degrad(tmp);
-		    mm_twilight (1);
+		    mm_twilight ();
 		}
 	    }
 	    break;
 
 	case NSTEP_FID:
 	    (void) sscanf (bp, "%d", &nstep);
-	    print_nstep (0);
+	    print_nstep ();
 	    break;
 
 	case PAUSE_FID:
 	    (void) sscanf (bp, "%lf", &tmp);
 	    mspause = (int)(tmp*1000 + 0.5);
-	    print_mspause (0);
+	    print_mspause ();
 	    break;
 
 	case TEMP_FID:
@@ -1778,7 +2031,7 @@ Field *fp;
 	case STPSZ_FID:
 	    mm_set_step_code (bp);
 	    set_t0 (&now);
-	    print_tminc(0);
+	    print_tminc();
 	    break;
 
 	default:
@@ -1898,25 +2151,26 @@ Field *fp;
 	    set_xmstring (prompt_w, XmNapplyLabelString, "00:00:00");
 	    break;
 	case DT_FID:
-	    if (autotz && pref_get (PREF_PRE_FILL) == PREF_PREFILL) {
-		/* strip "Auto" from prompt */
-		char *txt0, *txt;
+	    if (autodt) {
+		if (pref_get (PREF_PRE_FILL) == PREF_PREFILL) {
+		    /* strip "Auto" from prompt */
+		    char *txt0, *txt;
 
-		get_xmstring (fp->pb_w, XmNlabelString, &txt0);
-		for (txt = txt0; *txt && !isdigit(*txt); txt++)
-		    continue;
-		set_xmstring (prompt_w, XmNtextString, txt);
-		XtFree (txt0);
+		    get_xmstring (fp->pb_w, XmNlabelString, &txt0);
+		    for (txt = txt0; *txt && !isdigit(*txt); txt++)
+			continue;
+		    set_xmstring (prompt_w, XmNtextString, txt);
+		    XtFree (txt0);
+		}
+	    } else {
+		XtManageChild (aw);
+		set_xmstring (prompt_w, XmNapplyLabelString, "Auto");
 	    }
 	    break;
 	case STPSZ_FID:
 	    XtManageChild (steps_w);
 	    break;
 	case EPOCH_FID:
-	    if (sf_ison()) {
-		xe_msg("Epoch must remain matched to FITS image in Sky View",1);
-		return;
-	    }
 	    XtManageChild (aw);
 	    if (epoch == EOD)
 		set_xmstring (prompt_w, XmNapplyLabelString, "2000");
@@ -2033,40 +2287,41 @@ char *bp;
 	if (bp[0] == 'r' || bp[0] == 'R')
 	    mm_step_option = RTC_SS_OPTION;
 	else {
-	    int hasd = 0, hass = 0;
-	    int bpl = strlen (bp);
-
-	    for (i = 0; i < bpl; i++)
-		if (bp[i] == 'd' || bp[i] == 'D') {
-		    hasd = 1;
-		    break;
-		}
-	    for (i = 0; i < bpl; i++)
-		if (bp[i] == 's' || bp[i] == 'S') {
-		    hass = 1;
-		    break;
-		}
-
 	    mm_step_option = NULL;
-
-	    if (hasd) {
-		/* contains a d so treat as a number of days */
-		double x;
-		if (sscanf (bp, "%lf", &x) == 1)
-		    tminc = x * 24.0;
-	    } else if (hass) {
-		/* contains an s so treat as a number of sidereal days */
-		double x;
-		if (sscanf (bp, "%lf", &x) == 1)
-		    tminc = x * 24.0 * SIDRATE;
-	    } else {
-		if (mm_step_option == RTC_SS_OPTION)
-		    tminc = 0;	/* no prior */
-		f_scansex (tminc, bp, &tminc);
-	    }
+	    if (strpbrk(bp, "dD"))
+		tminc = atod(bp) * 24.0;
+	    else if (strpbrk(bp, "sS"))
+		tminc = atod(bp) * 24.0 * SIDRATE;
+	    else
+		f_scansex (0.0, bp, &tminc);
 	}
 }
 
+/* draw the various marker pixmaps */
+static void
+mm_pms()
+{
+	Obj *op;
+	Pixmap moonpm;
+
+	/* dst */
+	set_something (dst_w, XmNlabelPixmap,
+				    autotz ? dst_pm : XmUNSPECIFIED_PIXMAP);
+
+	/* moon up/phase */
+	op = db_basic(MOON);
+	db_update (op);
+	moonpm = moon_pm[((int)((op->s_elong+202)/45))%NMOONBM];
+	set_something (moon_w, XmNlabelPixmap,
+				op->s_alt > 0 ? moonpm : XmUNSPECIFIED_PIXMAP);
+
+	/* sun up */
+	op = db_basic(SUN);
+	db_update (op);
+	set_something (sun_w, XmNlabelPixmap,
+				op->s_alt > 0 ? sun_pm : XmUNSPECIFIED_PIXMAP);
+}
+
 /* print all the time/date/where related stuff: the Now structure.
  * print in a nice order, based on the field locations, as much as possible.
  */
@@ -2079,8 +2334,8 @@ int all;
 	char buf[32];
 	double tmp;
 
-	set_something (dst_w, XmNlabelPixmap,
-				    autotz ? dst_pm : XmUNSPECIFIED_PIXMAP);
+
+	mm_pms();
 	f_string (fw(TZN_FID), tznm);
 	f_sexa (fw(TZONE_FID), tz, 3, 3600);
 	f_date (fw(LD_FID), mjd_day(lmjd));
@@ -2113,16 +2368,11 @@ int all;
 
 	    tmp = temp;
 	    if (pref_get(PREF_UNITS) == PREF_ENGLISH) {
-		tmp = 9.*temp/5. + 32.0;   /* want to see degrees F, not C */
-#ifdef XK_degree
-		(void) sprintf (buf, "%%5.1f %cF", XK_degree);
-	    } else
-		(void) sprintf (buf, "%%5.1f %cC", XK_degree);
-#else
-		(void) sprintf (buf, "%%5.1f F");
-	    } else
-		(void) sprintf (buf, "%%5.1f C");
-#endif
+		tmp = 9.*temp/5. + 32.0;   /* C -> F */
+		strcpy (buf, "%5.1f F");
+	    } else {
+		strcpy (buf, "%5.1f C");
+	    }
 	    f_double (fw(TEMP_FID), buf, tmp);
 
 	    tmp = pressure;
@@ -2149,14 +2399,12 @@ int all;
  */
 /* ARGSUSED */
 static void
-mm_twilight (force)
-int force;
+mm_twilight ()
 {
 	static char nope[] = "-----";
 	double dusk, dawn;
 	Now midnight;
 	int status;
-	char buf[64];
 
 	twilight_cir (&now, dip, &dawn, &dusk, &status);
 
@@ -2188,12 +2436,7 @@ int force;
 	}
 
 	/* dip */
-#ifdef XK_degree
-	(void) sprintf (buf, "%%g%c", XK_degree);
-#else
-	(void) sprintf (buf, "%%g degs");
-#endif
-	f_double (fw(DIP_FID), buf, raddeg(dip));
+	f_double (fw(DIP_FID), "%g", raddeg(dip));
 
 	/* LST at midnight tonight */
 	midnight = now;
@@ -2362,7 +2605,7 @@ XtPointer call;
 	/* go */
 	print_extrunning();
 	nstep = MANYSTEPS;
-	mm_go();
+	mm_go(0);
 }
 
 /* stop using an external file, if any */
@@ -2393,4 +2636,4 @@ static char *hlp[] = {
 }
 
 /* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mainmenu.c,v $ $Date: 2000/11/27 08:34:47 $ $Revision: 1.38 $ $Name:  $"};
+static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile: mainmenu.c,v $ $Date: 2001/10/15 02:56:26 $ $Revision: 1.59 $ $Name:  $"};
