@@ -1443,7 +1443,7 @@ int noinfo;
 	    ObjInfo *lp = &oinfo[i];
 	    Obj *op = lp->op;
 	    char dbbuf[64];
-	    int c;
+	    DMCol c;
 
 	    switch (lineno) {
 	    case 0:
